NO COST NO API EASY TO EMBED GAZE DETECTOR
pip install gazedetector
import gazedetector
gazedetector.run_server()
***it is version 1 trying to make it more freindly and easy to deploy in web app***
pip install gazedetector==0.1.0
****IN DEVELOPMENT STAGE*****
